@@ -1,7 +1,9 @@
-package mergo
+package mergo_test
 
 import (
 	"testing"
+
+	"dario.cat/mergo"
 )
 
 type PrivateSliceTest66 struct {
@@ -17,12 +19,15 @@ func TestPrivateSlice(t *testing.T) {
 	p2 := PrivateSliceTest66{
 		PublicStrings: []string{"six", "seven"},
 	}
-	if err := Merge(&p1, p2); err != nil {
-		t.Fatalf("Error during the merge: %v", err)
+
+	if err := mergo.Merge(&p1, p2); err != nil {
+		t.Errorf("Error during the merge: %v", err)
 	}
+
 	if len(p1.PublicStrings) != 3 {
-		t.Error("5 elements should be in 'PublicStrings' field")
+		t.Error("3 elements should be in 'PublicStrings' field, when no append")
 	}
+
 	if len(p1.privateStrings) != 2 {
 		t.Error("2 elements should be in 'privateStrings' field")
 	}
@@ -36,12 +41,15 @@ func TestPrivateSliceWithAppendSlice(t *testing.T) {
 	p2 := PrivateSliceTest66{
 		PublicStrings: []string{"six", "seven"},
 	}
-	if err := Merge(&p1, p2, WithAppendSlice); err != nil {
-		t.Fatalf("Error during the merge: %v", err)
+
+	if err := mergo.Merge(&p1, p2, mergo.WithAppendSlice); err != nil {
+		t.Errorf("Error during the merge: %v", err)
 	}
+
 	if len(p1.PublicStrings) != 5 {
 		t.Error("5 elements should be in 'PublicStrings' field")
 	}
+
 	if len(p1.privateStrings) != 2 {
 		t.Error("2 elements should be in 'privateStrings' field")
 	}
